import { Injectable } from '@nestjs/common';
import { PrismaService } from '../prisma.service';
import { MemoryVectorStore } from 'langchain/vectorstores/memory';
import { RecursiveCharacterTextSplitter } from 'langchain/text_splitter';
import { OllamaEmbeddings } from '@langchain/ollama';



const embeddings = new OllamaEmbeddings({
  model: 'llama2',
  baseUrl: 'http://host.docker.internal:11434',
});

@Injectable()
export class PostsService {
  constructor(private readonly prisma: PrismaService) {}

  async create(data: { text?: string; media?: string; mediaType?: string; code?: string; embedding?: number[] }) {
    const splitter = RecursiveCharacterTextSplitter.fromLanguage("markdown", {
      chunkSize: 500,
      chunkOverlap: 0,
    });
    const output = await splitter.createDocuments([data.text]);
    console.log(output)
    const vectorstore = await MemoryVectorStore.fromDocuments(output, embeddings);
    console.log(vectorstore);
    data.embedding ??= vectorstore.memoryVectors[0].embedding
    return this.prisma.post.create({
      data, 
    });
  }

  async findAll() {
    return this.prisma.post.findMany();
  }
}
