import React, { useState, useEffect } from 'react';
import axios from 'axios';
import ReactMarkdown from 'react-markdown';
import MarkdownEditor from 'react-markdown-editor-lite';
import 'react-markdown-editor-lite/lib/index.css';
import MarkdownIt from 'markdown-it';

// Инициализация MarkdownIt
const mdParser = new MarkdownIt();

const Posts = () => {
  const [posts, setPosts] = useState([]);
  const [text, setText] = useState('');

  const axiosInstance = axios.create({
    baseURL: 'http://localhost:3000',
    headers: {
      Authorization: process.env.REACT_APP_SERVICE_TOKEN,
    },
  });

  useEffect(() => {
    fetchPosts();
  }, []);

  const fetchPosts = async () => {
    try {
      const response = await axiosInstance.get('/posts');
      setPosts(response.data);
    } catch (error) {
      console.error('Error fetching posts:', error);
    }
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    try {
      const newPost = { text };
      await axiosInstance.post('/posts', newPost);
      fetchPosts(); // Обновляем список постов после создания нового
      setText('');
    } catch (error) {
      console.error('Error creating post:', error);
    }
  };

  const handleEditorChange = ({ text }) => {
    setText(text);
  };

  return (
    <div>
      <h1>Posts</h1>
      <form onSubmit={handleSubmit}>
        <MarkdownEditor
          value={text}
          style={{ height: '300px' }}
          renderHTML={(text) => mdParser.render(text)}
          onChange={handleEditorChange}
        />
        <button type="submit">Create Post</button>
      </form>
      <h2>All Posts</h2>
      <ul>
        {posts.map((post, index) => (
          <li key={index}>
            <ReactMarkdown>{post.text}</ReactMarkdown>
          </li>
        ))}
      </ul>
    </div>
  );
};

export default Posts;